From: "Alessandro Suardi" <alessandro.suardi@gmail.com>
To: "Linux Kernel" <linux-kernel@vger.kernel.org>
Subject: 40% IDE performance regression going from FC3 to FC5 with same kernel
Date: Sat, 8 Apr 2006 16:47:18 +0200 [thread overview]
Message-ID: <5a4c581d0604080747w61464d48k5480391d98b2bc47@mail.gmail.com> (raw)
[-- Attachment #1: Type: text/plain, Size: 2866 bytes --]
I'll be filing a FC5 performance bug for this but would like an opinion
from the IDE kernel people just in case this has already been seen...
I just upgraded my home K7-800, 512MB RAM box from FC3 to FC5
and noticed a disk performance slowdown while copying files around.
System has two 160GB disks, a Samsung SP1604N 2MB cache and
a Maxtor 6Y160P0 8MB cache; both disks appear to be almost 2x
slower both on hdparm -t tests (17-19MB/s against 33/35 MB/s) and
on dd tests, like this:
FC3
[root@donkey tmp]# time dd if=/dev/hda of=/dev/null skip=200 bs=1024k count=200
200+0 records in
200+0 records out
real 0m4.623s
user 0m0.004s
sys 0m1.308s
FC5
[root@donkey tmp]# time dd if=/dev/hda of=/dev/null skip=200 bs=1024k count=200
200+0 records in
200+0 records out
209715200 bytes (210 MB) copied, 9.67808 seconds, 21.7 MB/s
real 0m9.683s
user 0m0.008s
sys 0m1.400s
The initial tests were my last FC3 self-compiled kernel (2.6.16-rc5-git8)
vs FC5's 2.6.16-1.2080_FC5 kernel; so just to be sure, I copied over
from my FC3 partition the 2.6.16-rc5-git8 kernel and its config file,
and rebuilt it under FC5, with just a few differences for the new USB
2.0 disk I added to a PCI controller I just put in, namely
[root@donkey linux-2.6.16-rc5-git8]# diff .config
/fc3/usr/src/linux-2.6.16-rc5-git8/.config
4c4
< # Fri Apr 7 03:58:23 2006
---
> # Mon Mar 6 22:49:32 2006
1110,1112c1110
< CONFIG_USB_EHCI_HCD=m
< CONFIG_USB_EHCI_SPLIT_ISO=y
< CONFIG_USB_EHCI_ROOT_HUB_TT=y
---
> # CONFIG_USB_EHCI_HCD is not set
1115c1113
< CONFIG_USB_UHCI_HCD=m
---
> CONFIG_USB_UHCI_HCD=y
1218d1215
< # CONFIG_USB_SISUSBVGA is not set
The result is unexpected - performance delta is still there. Concatenating
output from hdparm -i /dev/hda and hdparm /dev/hda for the same kernel
under FC3 and FC5, the only difference is
[root@donkey ~]# diff /tmp/hdparm.out.2616rc2git8-fc5
/tmp/hdparm.out.2616rc2git8
14c14
< Drive conforms to: (null): ATA/ATAPI-1 ATA/ATAPI-2 ATA/ATAPI-3
ATA/ATAPI-4 ATA/ATAPI-5 ATA/ATAPI-6 ATA/ATAPI-7
---
> Drive conforms to: (null):
27c27
< geometry = 19457/255/63, sectors = 312581808, start = 0
---
> geometry = 19457/255/63, sectors = 160041885696, start = 0
I'll try now and rebuild a 2.6.16-rc5-git8 kernel under FC5 with the
FC3 GCC and see whether that is responsible for the performance
drop... of course if anyone has any idea about what's going on, I
will be happy to try out stuff. Attaching hdparm output from the FC5
2.6.16-rc5-git8 just to show that there is DMA etc. all configured fine.
Thanks in advance, ciao,
--alessandro
"Dreamer ? Each one of us is a dreamer. We just push it down deep because
we are repeatedly told that we are not allowed to dream in real life"
(Reinhold Ziegler)
[-- Attachment #2: hdparm.out.2616rc5git8-fc5 --]
[-- Type: application/octet-stream, Size: 954 bytes --]
/dev/hda:
Model=SAMSUNG SP1604N, FwRev=TM100-24, SerialNo=0773J1FWC32580
Config={ HardSect NotMFM HdSw>15uSec Fixed DTR>10Mbs }
RawCHS=16383/16/63, TrkSize=34902, SectSize=554, ECCbytes=4
BuffType=DualPortCache, BuffSize=2048kB, MaxMultSect=16, MultSect=off
CurCHS=17475/15/63, CurSects=16513875, LBA=yes, LBAsects=268435455
IORDY=on/off, tPIO={min:240,w/IORDY:120}, tDMA={min:120,rec:120}
PIO modes: pio0 pio1 pio2 pio3 pio4
DMA modes: mdma0 mdma1 mdma2
UDMA modes: udma0 udma1 udma2 udma3 *udma4 udma5
AdvancedPM=no WriteCache=enabled
Drive conforms to: (null): ATA/ATAPI-1 ATA/ATAPI-2 ATA/ATAPI-3 ATA/ATAPI-4 ATA/ATAPI-5 ATA/ATAPI-6 ATA/ATAPI-7
* signifies the current active mode
/dev/hda:
multcount = 0 (off)
IO_support = 1 (32-bit)
unmaskirq = 1 (on)
using_dma = 1 (on)
keepsettings = 0 (off)
readonly = 0 (off)
readahead = 256 (on)
geometry = 19457/255/63, sectors = 312581808, start = 0
next reply other threads:[~2006-04-08 14:47 UTC|newest]
Thread overview: 15+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-04-08 14:47 Alessandro Suardi [this message]
2006-04-08 15:34 ` Alessandro Suardi
2006-04-08 15:45 ` Arjan van de Ven
2006-04-08 16:27 ` Alessandro Suardi
2006-04-08 16:36 ` Arjan van de Ven
2006-04-08 17:07 ` Alessandro Suardi
2006-04-11 11:26 ` Jan Engelhardt
2006-04-11 18:04 ` Alessandro Suardi
2006-04-11 18:41 ` Jan Engelhardt
2006-04-11 12:28 ` Andreas Mohr
2006-04-11 18:11 ` Alessandro Suardi
2006-04-11 18:43 ` Jan Engelhardt
2006-04-11 19:49 ` Alessandro Suardi
2006-04-11 22:06 ` Alessandro Suardi
2006-04-11 19:31 ` Bill Davidsen
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=5a4c581d0604080747w61464d48k5480391d98b2bc47@mail.gmail.com \
--to=alessandro.suardi@gmail.com \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®